<html>
  <head>
   <style type="text/css">
    a {text-decoration:none; color: {{ colors.linkColor }} }
   </style>
  </head>
  <body text="{{ colors.textColor }}" bgcolor="{{ colors.backgroundColor }}">
  {% include "contact_embedded.html" %}
  </body>
</html>
