
#ifndef KADDRESSBOOK_IMPORTEXPORT_EXPORT_H
#define KADDRESSBOOK_IMPORTEXPORT_EXPORT_H

#ifdef KADDRESSBOOK_IMPORTEXPORT_STATIC_DEFINE
#  define KADDRESSBOOK_IMPORTEXPORT_EXPORT
#  define KADDRESSBOOK_IMPORTEXPORT_NO_EXPORT
#else
#  ifndef KADDRESSBOOK_IMPORTEXPORT_EXPORT
#    ifdef KPim6AddressbookImportExport_EXPORTS
        /* We are building this library */
#      define KADDRESSBOOK_IMPORTEXPORT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KADDRESSBOOK_IMPORTEXPORT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KADDRESSBOOK_IMPORTEXPORT_NO_EXPORT
#    define KADDRESSBOOK_IMPORTEXPORT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KADDRESSBOOK_IMPORTEXPORT_DEPRECATED
#  define KADDRESSBOOK_IMPORTEXPORT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KADDRESSBOOK_IMPORTEXPORT_DEPRECATED_EXPORT
#  define KADDRESSBOOK_IMPORTEXPORT_DEPRECATED_EXPORT KADDRESSBOOK_IMPORTEXPORT_EXPORT KADDRESSBOOK_IMPORTEXPORT_DEPRECATED
#endif

#ifndef KADDRESSBOOK_IMPORTEXPORT_DEPRECATED_NO_EXPORT
#  define KADDRESSBOOK_IMPORTEXPORT_DEPRECATED_NO_EXPORT KADDRESSBOOK_IMPORTEXPORT_NO_EXPORT KADDRESSBOOK_IMPORTEXPORT_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KADDRESSBOOK_IMPORTEXPORT_NO_DEPRECATED
#    define KADDRESSBOOK_IMPORTEXPORT_NO_DEPRECATED
#  endif
#endif

#endif /* KADDRESSBOOK_IMPORTEXPORT_EXPORT_H */
